@@ -42,39 +42,44 @@ class Log(QTextBrowser):
         self._types = job.ALL
         self._lasttype = None
         self._formats = self.logformats()
-        
+
     def setMessageTypes(self, types):
         """Set the types of Job output to display.
-        
+
         types is a constant bitmask from job, like job.STDOUT etc.
         By default job.ALL is used.
-        
+
         """
         self._types = types
-    
+
     def messageTypes(self):
         """Return the set message types (job.ALL by default)."""
         return self._types
-    
-    def connectJob(self, job):
+
+    def connectJob(self, j):
         """Gives us the output from the Job (past and upcoming)."""
-        for msg, type in job.history():
+        for msg, type in j.history():
             self.write(msg, type)
-        job.output.connect(self.write)
-        
+        j.output.connect(self.write)
+
+    def disconnectJob(self, j):
+        """Disconnects from an aborted job
+        (to avoid calling into a destroyed log widget)."""
+        j.output.disconnect(self.write)
+
     def textFormat(self, type):
         """Returns a QTextFormat() for the given type."""
         return self._formats[type]
 
     def write(self, message, type):
         """Writes the given message with the given type to the log.
-        
+
         The keepScrolledDown context manager is used to scroll the log further
         down if it was scrolled down at that moment.
-        
+
         If two messages of a different type are written after each other a newline
         is inserted if otherwise the message would continue on the same line.
-        
+
         """
         if type & self._types:
             with self.keepScrolledDown():
@@ -83,11 +88,11 @@ class Log(QTextBrowser):
                 if changed and self.cursor.block().text() and not message.startswith('\n'):
                     self.cursor.insertText('\n')
                 self.writeMessage(message, type)
-    
+
     def writeMessage(self, message, type):
         """Inserts the given message in the text with the textformat belonging to type."""
         self.cursor.insertText(message, self.textFormat(type))
-    
+
     @contextlib.contextmanager
     def keepScrolledDown(self):
         """Performs a function, ensuring the log stays scrolled down if it was scrolled down on start."""
@@ -98,50 +103,48 @@ class Log(QTextBrowser):
         finally:
             if scrolleddown:
                 vbar.setValue(vbar.maximum())
-    
+
     def logformats(self):
         """Returns a dictionary with QTextCharFormats for the different types of messages.
-        
+
         Besides the STDOUT, STDERR, NEUTRAL, FAILURE and SUCCESS formats there is also
         a "link" format, that looks basically the same as the output formats, but blueish
         and underlined, to make parts of the output (e.g. filenames) look clickable.
-        
+
         """
         textColor = QApplication.palette().color(QPalette.WindowText)
         successColor = qutil.addcolor(textColor, 0, 128, 0) # more green
         failureColor = qutil.addcolor(textColor, 128, 0, 0) # more red
         linkColor    = qutil.addcolor(textColor, 0, 0, 128) # more blue
         stdoutColor  = qutil.addcolor(textColor, 64, 64, 0) # more purple
-        
+
         s = QSettings()
         s.beginGroup("log")
         outputFont = QFont(s.value("fontfamily", "monospace", str))
         outputFont.setPointSizeF(s.value("fontsize", 9.0, float))
-        
+
         output = QTextCharFormat()
         output.setFont(outputFont)
-        # enable zooming the log font size
-        output.setProperty(QTextFormat.FontSizeAdjustment, 0)
-        
+
         stdout = QTextCharFormat(output)
         stdout.setForeground(stdoutColor)
-        
+
         stderr = QTextCharFormat(output)
         link   = QTextCharFormat(output)
         link.setForeground(linkColor)
         link.setFontUnderline(True)
-        
-        status = QTextCharFormat()
+
+        status = QTextCharFormat(output)
         status.setFontWeight(QFont.Bold)
-        
+
         neutral = QTextCharFormat(status)
-        
+
         success = QTextCharFormat(status)
         success.setForeground(successColor)
-        
+
         failure = QTextCharFormat(status)
         failure.setForeground(failureColor)
-        
+
         return {
             job.STDOUT: stdout,
             job.STDERR: stderr,
@@ -150,6 +153,3 @@ class Log(QTextBrowser):
             job.FAILURE: failure,
             'link': link,
         }
-
-
-
