@@ -93,6 +93,13 @@ class MainWindow(QMainWindow):
         QMainWindow.__init__(self)
         self.setAttribute(Qt.WA_DeleteOnClose)
 
+        # Add option to nest docks (useful on large screens)
+        self.setDockOptions(
+            QMainWindow.AllowNestedDocks |
+            QMainWindow.AnimatedDocks |
+             QMainWindow.AllowTabbedDocks
+        )
+
         # this could be made configurable
         self.setCorner(Qt.TopLeftCorner, Qt.LeftDockWidgetArea)
         self.setCorner(Qt.BottomLeftCorner, Qt.LeftDockWidgetArea)
@@ -150,6 +157,7 @@ class MainWindow(QMainWindow):
         app.settingsChanged.connect(self.settingsChanged)
         self.settingsChanged()
 
+
     def documents(self):
         """Returns the list of documents in the order of the TabBar."""
         return self.tabBar.documents()
