@@ -22,82 +22,73 @@ A widget and dialog to show an output preview of a LilyPond document.
 """
 
 
-
 import os
-import glob
-import shutil
 
-from PyQt5.QtCore import QSettings, QSize
+from PyQt5.QtCore import (
+    QSize,
+    Qt
+)
 from PyQt5.QtWidgets import (QComboBox, QDialog, QDialogButtonBox, QHBoxLayout,
                              QLabel, QStackedLayout, QVBoxLayout, QWidget)
 
-import ly.document
-import ly.docinfo
-
 import app
-import codecs
 import icons
-import job
+import job.lilypond
 import log
-import util
 import qutil
-import lilypondinfo
-import popplerview
-import popplertools
+import pagedview
 import widgets.progressbar
 
 
-class MusicPreviewJob(job.Job):
-    def __init__(self, text, title=None):
-        super(MusicPreviewJob, self).__init__()
-        self.decode_errors = 'replace'
-        self.decoder_stdout = self.decoder_stderr = codecs.getdecoder('utf-8')
-        self.directory = util.tempdir()
-        self.document = os.path.join(self.directory, 'document.ly')
-        with open(self.document, 'wb') as f:
-            f.write(text.encode('utf-8'))
-            
-        info = lilypondinfo.preferred()
-        if QSettings().value("lilypond_settings/autoversion", True, bool):
-            version = ly.docinfo.DocInfo(ly.document.Document(text, 'lilypond')).version()
-            if version:
-                info = lilypondinfo.suitable(version)
-        
-        lilypond = info.abscommand() or info.command
-        self.command = [lilypond, '-dno-point-and-click', '--pdf', self.document]
-        if title:
-            self.set_title(title)
-    
-    def resultfiles(self):
-        return glob.glob(os.path.join(self.directory, '*.pdf'))
-        
-    def cleanup(self):
-        shutil.rmtree(self.directory, ignore_errors=True)
-
-
 class MusicPreviewWidget(QWidget):
-    def __init__(self, parent=None):
+    def __init__(
+        self,
+        parent=None,
+        showProgress=True,
+        showWaiting=False,
+        progressHidden=False,
+        progressHiddenWhileIdle=True,
+        progressShowFinished=3000,
+        showLog=True
+    ):
         super(MusicPreviewWidget, self).__init__(parent)
         self._lastbuildtime = 10.0
         self._running = None
         self._current = None
-        
+
+        self._showLog = showLog
+        if showLog:
+            self._log = log.Log()
+        self._showProgress = showProgress
+
         self._chooserLabel = QLabel()
         self._chooser = QComboBox(self, activated=self.selectDocument)
-        self._log = log.Log()
-        self._view = popplerview.View()
-        self._progress = widgets.progressbar.TimedProgressBar()
-        
+        self._view = pagedview.PagedView()
+        self._view.setMagnifier(pagedview.Magnifier())
+
+        self._showWaiting = showWaiting
+        if showWaiting:
+            from widgets.waitingoverlay import Overlay
+            self._waiting = Overlay(self._view)
+            self._waiting.hide()
+
         self._stack = QStackedLayout()
         self._top = QWidget()
-        
-        layout = QVBoxLayout()
+
+        layout = QVBoxLayout(margin=0)
         self.setLayout(layout)
-        
+
         layout.addWidget(self._top)
         layout.addLayout(self._stack)
-        layout.addWidget(self._progress)
-        
+        if self._showProgress:
+            self._progress = widgets.progressbar.TimedProgressBar(
+                parent=self,
+                hidden=progressHidden,
+                hideWhileIdle=progressHiddenWhileIdle,
+                showFinished=progressShowFinished
+            )
+            layout.addWidget(self._progress)
+
         top = QHBoxLayout()
         top.setContentsMargins(0, 0, 0, 0)
         top.setSpacing(2)
@@ -105,45 +96,86 @@ class MusicPreviewWidget(QWidget):
         top.addWidget(self._chooserLabel)
         top.addWidget(self._chooser)
         top.addStretch(1)
-        
-        self._stack.addWidget(self._log)
+
+        if showLog:
+            self._stack.addWidget(self._log)
         self._stack.addWidget(self._view)
-        
+
         self._top.hide()
         app.aboutToQuit.connect(self.cleanup)
         app.translateUI(self)
-    
+
     def translateUI(self):
         self._chooserLabel.setText(_("Document:"))
-        
-    def preview(self, text, title=None):
+
+    def abort_running(self):
+        """Ensures no running job is left behind.
+        This *can* be called by the using dialog/widget."""
+        j = self._running
+        if j and j.is_running():
+            if self._showLog:
+                self._log.disconnectJob(j)
+            j.done.disconnect(self._done)
+            j.abort()
+
+    def preview(
+        self, text, title=None, base_dir=None,
+        temp_dir='', cached=False
+    ):
         """Runs LilyPond on the given text and shows the resulting PDF."""
-        j = self._running = MusicPreviewJob(text, title)
+        self.abort_running()
+        if cached:
+            self._running = j = job.lilypond.CachedPreviewJob(
+                text,
+                target_dir=temp_dir,
+                base_dir=base_dir,
+                title=title
+            )
+            if not self._running.needs_compilation():
+                self._done(None)
+                return
+        else:
+            self._running = j = job.lilypond.VolatileTextJob(
+                text,
+                title=title
+            )
         j.done.connect(self._done)
-        self._log.clear()
-        self._log.connectJob(j)
-        j.start()
-        self._progress.start(self._lastbuildtime)
-    
+        if self._showLog:
+            self._log.clear()
+            self._log.connectJob(j)
+            self._stack.setCurrentWidget(self._log)
+        if self._showProgress:
+            j.started.connect(
+                lambda: self._progress.start(self._lastbuildtime)
+            )
+            self._progress.start(self._lastbuildtime)
+        if self._showWaiting:
+            self._waiting.start()
+        app.job_queue().add_job(j, 'generic')
+
     def _done(self, success):
-        self._progress.stop(False)
+        # TODO: Handle failed compilation (= no file to show)
+        if self._showProgress:
+            self._progress.stop()
+        if self._showWaiting:
+            self._waiting.stop()
         pdfs = self._running.resultfiles()
         self.setDocuments(pdfs)
-        if not pdfs:
+        if not pdfs and self._showLog:
             self._stack.setCurrentWidget(self._log)
             return
         self._lastbuildtime = self._running.elapsed_time()
         self._stack.setCurrentWidget(self._view)
         if self._current:
             self._current.cleanup()
-        self._current = self._running # keep the tempdir
+        self._current = self._running  # keep the tempdir
         self._running = None
-        
+
     def setDocuments(self, pdfs):
         """Loads the given PDF path names in the UI."""
-        self._documents = [popplertools.Document(name) for name in pdfs]
+        self._documents = [pagedview.loadPdf(name) for name in pdfs]
         self._chooser.clear()
-        self._chooser.addItems([d.name() for d in self._documents])
+        self._chooser.addItems([os.path.basename(d.filename()) for d in self._documents])
         self._top.setVisible(len(self._documents) > 1)
         if pdfs:
             self._chooser.setCurrentIndex(0)
@@ -152,9 +184,7 @@ class MusicPreviewWidget(QWidget):
             self._view.clear()
 
     def selectDocument(self, index):
-        doc = self._documents[index].document()
-        if doc:
-            self._view.load(doc)
+        self._view.setDocument(self._documents[index])
 
     def cleanup(self):
         if self._running:
@@ -164,16 +194,15 @@ class MusicPreviewWidget(QWidget):
         if self._current:
             self._current.cleanup()
             self._current = None
-        self._stack.setCurrentWidget(self._log)
+        if self._showLog:
+            self._stack.setCurrentWidget(self._log)
         self._top.hide()
         self._view.clear()
-    
+
     def print_(self):
         """Prints the currently displayed document."""
-        if self._documents:
-            doc = self._documents[self._chooser.currentIndex()]
-            import popplerprint
-            popplerprint.printDocument(doc, self)
+        if self._view.document():
+            self._view.print()
 
 
 class MusicPreviewDialog(QDialog):
@@ -194,11 +223,11 @@ class MusicPreviewDialog(QDialog):
         self._printButton.hide()
         qutil.saveDialogSize(self, "musicpreview/dialog/size", QSize(500, 350))
         app.translateUI(self)
-    
+
     def translateUI(self):
         self._printButton.setText(_("&Print"))
         self.setWindowTitle(app.caption(_("Music Preview")))
-        
+
     def preview(self, text, title=None):
         self._widget.preview(text, title)
 
@@ -208,5 +237,3 @@ class MusicPreviewDialog(QDialog):
     def setEnablePrintButton(self, enable):
         """Enables or disables the print button."""
         self._printButton.setVisible(enable)
-
-
