@@ -21,13 +21,13 @@
 The PDF preview panel widget.
 """
 
-from __future__ import division
 
+
+import collections
 import itertools
 import os
-import weakref
 
-from PyQt5.QtCore import pyqtSignal, QPoint, QRect, Qt, QTimer, QUrl
+from PyQt5.QtCore import pyqtSignal, QMargins, QPoint, QRect, QSettings, Qt, QUrl
 from PyQt5.QtGui import QCursor, QTextCharFormat
 from PyQt5.QtWidgets import QToolTip, QVBoxLayout, QWidget
 
@@ -36,8 +36,11 @@ try:
 except ImportError:
     pass
 
-import qpopplerview
-import popplerview
+import qpageview
+import qpageview.layout
+import qpageview.highlight
+import qpageview.rubberband
+import pagedview
 
 import app
 import icons
@@ -53,97 +56,80 @@ from . import pointandclick
 
 class MusicView(QWidget):
     """Widget containing the qpopplerview.View."""
-    
-    zoomChanged = pyqtSignal(int, float) # mode, scale
-    
     def __init__(self, dockwidget):
         """Creates the Music View for the dockwidget."""
         super(MusicView, self).__init__(dockwidget)
-        
-        self._positions = weakref.WeakKeyDictionary()
-        self._currentDocument = None
+
         self._links = None
         self._clicking_link = False
-        
+
         self._highlightFormat = QTextCharFormat()
-        self._highlightMusicFormat = Highlighter()
+        self._highlightMusicFormat = qpageview.highlight.Highlighter()
         self._highlightRange = None
-        self._highlightTimer = QTimer(singleShot=True, interval= 250, timeout=self.updateHighlighting)
-        self._highlightRemoveTimer = QTimer(singleShot=True, timeout=self.clearHighlighting)
-        
+
         layout = QVBoxLayout()
         layout.setContentsMargins(0, 0, 0, 0)
         self.setLayout(layout)
-        
-        self.view = popplerview.View(self)
-        self.view.MAX_ZOOM = 8.0
+
+        self.view = pagedview.PagedView(self)
+        self.view.setRubberband(qpageview.rubberband.Rubberband())
         layout.addWidget(self.view)
         app.settingsChanged.connect(self.readSettings)
         self.readSettings()
-        self.view.setViewMode(qpopplerview.FitWidth)
-        self.view.surface().setPageLayout(qpopplerview.RowLayout())
-        self.view.surface().linkClicked.connect(self.slotLinkClicked)
-        self.view.surface().linkHovered.connect(self.slotLinkHovered)
-        self.view.surface().linkLeft.connect(self.slotLinkLeft)
-        self.view.surface().setShowUrlTips(False)
-        self.view.surface().linkHelpRequested.connect(self.slotLinkHelpRequested)
-        
-        self.view.viewModeChanged.connect(self.updateZoomInfo)
-        self.view.surface().pageLayout().scaleChanged.connect(self.updateZoomInfo)
+        self.view.setLinkHighlighter(qpageview.highlight.Highlighter())
+        self.view.linkClicked.connect(self.slotLinkClicked)
+        self.view.linkHovered.connect(self.slotLinkHovered)
+        self.view.linkLeft.connect(self.slotLinkLeft)
+        #self.view.setShowUrlTips(False)
+        self.view.linkHelpRequested.connect(self.slotLinkHelpRequested)
+
         self.view.setContextMenuPolicy(Qt.CustomContextMenu)
         self.view.customContextMenuRequested.connect(self.showContextMenu)
-        
+
         # react if cursor of current text document moves
         dockwidget.mainwindow().currentViewChanged.connect(self.slotCurrentViewChanged)
         view = dockwidget.mainwindow().currentView()
         if view:
             self.slotCurrentViewChanged(view)
-    
+
     def sizeHint(self):
         """Returns the initial size the PDF (Music) View prefers."""
         return self.parent().mainwindow().size() / 2
-    
-    def updateZoomInfo(self):
-        """Called when zoom and viewmode of the qpopplerview change, emit zoomChanged."""
-        self.zoomChanged.emit(self.view.viewMode(), self.view.surface().pageLayout().scale())
-    
+
     def openDocument(self, doc):
-        """Opens a documents.Document instance."""
-        self.clear()
-        self._currentDocument = doc
+        """Open a qpageview.Document instance."""
+        self._links = None
+        self._highlightRange = None
         document = doc.document()
         if document:
             self._links = pointandclick.links(document)
-            self.view.load(document)
-            position = self._positions.get(doc, (0, 0, 0))
-            self.view.setPosition(position, True)
+        self.view.setDocument(doc)
 
     def clear(self):
         """Empties the view."""
-        cur = self._currentDocument
-        if cur:
-            self._positions[cur] = self.view.position()
-        self._currentDocument = None
         self._links = None
         self._highlightRange = None
-        self._highlightTimer.stop()
         self.view.clear()
-        
+
     def readSettings(self):
         """Reads the settings from the user's preferences."""
         # background and highlight colors of music view
         colors = textformats.formatData('editor').baseColors
-        self._highlightMusicFormat.setColor(colors['musichighlight'])
+        self._highlightMusicFormat.color = colors['musichighlight']
         color = colors['selectionbackground']
         color.setAlpha(128)
         self._highlightFormat.setBackground(color)
+        if QSettings().value("musicview/document_properties", True, bool):
+            self.view.documentPropertyStore.mask = None
+        else:
+            self.view.documentPropertyStore.mask = ('position')
 
     def slotLinkClicked(self, ev, page, link):
         """Called when the use clicks a link.
-        
+
         If the links is a textedit link, opens the document and puts the cursor there.
         Otherwise, call the helpers module to open the destination.
-        
+
         """
         if ev.button() == Qt.RightButton:
             return
@@ -162,159 +148,121 @@ class MusicView(QWidget):
                 widgets.blink.Blinker.blink_cursor(mainwindow.currentView())
                 mainwindow.activateWindow()
                 mainwindow.currentView().setFocus()
-        elif (isinstance(link, popplerqt5.Poppler.LinkBrowse)
-              and not link.url().startswith('textedit:')):
-            helpers.openUrl(QUrl(link.url()))
-        elif (isinstance(link, popplerqt5.Poppler.LinkGoto)
-              and not link.isExternal()):
-            self.view.gotoPageNumber(link.destination().pageNumber() - 1)
+        elif link.url and not link.url.startswith('textedit:'):
+            helpers.openUrl(QUrl(link.url))
+        elif (hasattr(link, "linkobj") and isinstance(link.linkobj, popplerqt5.Poppler.LinkGoto)
+              and not link.linkobj.isExternal()):
+            self.view.setCurrentPageNumber(link.linkobj.destination().pageNumber())
 
     def slotLinkHovered(self, page, link):
         """Called when the mouse hovers a link.
-        
+
         If the links points to the current editor document, the token(s) it points
         at are highlighted using a transparent selection color.
-        
+
         The highlight shows for a few seconds but disappears when the mouse moves
         off the link or when the link is clicked.
-        
+
         """
-        self.view.surface().highlight(self._highlightMusicFormat,
-            [(page, link.linkArea().normalized())], 2000)
-        self._highlightRange = None
         cursor = self._links.cursor(link)
         if not cursor or cursor.document() != self.parent().mainwindow().currentDocument():
             return
-        
+
         # highlight token(s) at this cursor
         cursors = pointandclick.positions(cursor)
         if cursors:
             view = self.parent().mainwindow().currentView()
             viewhighlighter.highlighter(view).highlight(self._highlightFormat, cursors, 2, 5000)
-    
+
     def slotLinkLeft(self):
         """Called when the mouse moves off a previously highlighted link."""
-        self.clearHighlighting()
         view = self.parent().mainwindow().currentView()
         viewhighlighter.highlighter(view).clear(self._highlightFormat)
 
-    def slotLinkHelpRequested(self, pos, page, link):
+    def slotLinkHelpRequested(self, ev, page, link):
         """Called when a ToolTip wants to appear above the hovered link."""
-        if isinstance(link, popplerqt5.Poppler.LinkBrowse):
+        pos = self.view.viewport().mapToGlobal(ev.pos())
+        if link.url:
             cursor = self._links.cursor(link)
             if cursor:
                 import documenttooltip
                 text = documenttooltip.text(cursor)
-            elif link.url():
-                l = textedit.link(link.url())
+            else:
+                l = textedit.link(link.url)
                 if l:
                     text = "{0} ({1}:{2})".format(os.path.basename(l.filename), l.line, l.column)
                 else:
-                    text = link.url()
-        elif isinstance(link, popplerqt5.Poppler.LinkGoto):
-            text = _("Page {num}").format(num=link.destination().pageNumber())
-            if link.isExternal():
-                text = link.fileName() + "\n" + text
+                    text = link.url
+        elif hasattr(link, "linkobj") and isinstance(link.linkobj, popplerqt5.Poppler.LinkGoto):
+            text = _("Page {num}").format(num=link.linkobj.destination().pageNumber())
+            if link.linkobj.isExternal():
+                text = link.linkobj.fileName() + "\n" + text
         else:
             return
-        QToolTip.showText(pos, text, self.view.surface(), page.linkRect(link.linkArea()))
+        QToolTip.showText(pos, text, self.view, page.linkRect(link))
 
     def slotCurrentViewChanged(self, view, old=None):
-        self.view.surface().clearHighlight(self._highlightMusicFormat)
+        self.view.clearHighlight(self._highlightMusicFormat)
         if old:
             old.cursorPositionChanged.disconnect(self.slotCursorPositionChanged)
         view.cursorPositionChanged.connect(self.slotCursorPositionChanged)
-    
+
     def slotCursorPositionChanged(self):
         """Called when the user moves the text cursor."""
+        self.showCurrentLinks(
+            not self._clicking_link
+            and self.parent().actionCollection.music_sync_cursor.isChecked())
+
+    def showCurrentLinks(self, scroll=False, msec=None):
+        """Show objects at current text cursor.
+
+        If scroll is True, also scrolls the view if needed. If msec is given,
+        objects are highlighed that long. If not given, a default time is used.
+
+        """
         if not self.isVisible() or not self._links:
             return # not visible of no PDF in the viewer
-        
+
         view = self.parent().mainwindow().currentView()
         links = self._links.boundLinks(view.document())
         if not links:
             return # the PDF contains no references to the current text document
-        
-        s = links.indices(view.textCursor())
-        if s is False:
-            self.clearHighlighting()
-        elif s:
-            # move if sync is enabled and the cursor did not move as a result of
-            # clicking a link
-            if (not self._clicking_link
-                and self.parent().actionCollection.music_sync_cursor.isChecked()):
-                rect = self.destinationsRect(links.destinations()[s])
-                center = rect.center()
-                self.view.ensureVisible(center.x(), center.y(),
-                                        50 + rect.width() // 2,
-                                        50 + rect.height() // 2)
-            
-            # perform highlighting after move has been started. This is to ensure that if kinetic scrolling is
-            # is enabled its speed is already set so that we can adjust the highlight timer.
-            self.highlight(links.destinations(), s)
 
-
-    def highlight(self, destinations, slice, msec=None):
-        """(Internal) Highlights the from the specified destinations the specified slice."""
-        count = slice.stop - slice.start
-        if msec is None:
-            # RC: increased timer to give some time to the kinetic scrolling to complete.
-            kineticTimeLeft = 0
-            if self.view.kineticScrollingEnabled():
-                kineticTimeLeft = 20*self.view.kineticTicksLeft() 
-            msec = 5000 if count > 1 else 2000 # show selections longer
-            msec += kineticTimeLeft
-        self._highlightRemoveTimer.start(msec)
-        if self._highlightRange == slice:
-            return # don't redraw if same
-        self._highlightRange = slice
-        self._destinations = destinations[slice]
-        if count > 100:
-            self._highlightTimer.start()
-        else:
-            self._highlightTimer.stop()
-            self.updateHighlighting()
-    
-    def updateHighlighting(self):
-        """Really orders the view's surface to draw the highlighting."""
-        layout = self.view.surface().pageLayout()
-        areas = [(layout[pageNum], rect)
-                    for dest in self._destinations
-                    for pageNum, rect in dest]
-        self.view.surface().highlight(self._highlightMusicFormat, areas)
-    
-    def clearHighlighting(self):
-        """Called on timeout of the _highlightRemoveTimer."""
-        self._highlightRange = None
-        self.view.surface().clearHighlight(self._highlightMusicFormat)
-
-    def showCurrentLinks(self):
-        """Scrolls the view if necessary to show objects at current text cursor."""
-        if not self._links:
-            return # no PDF in viewer
-            
-        view = self.parent().mainwindow().currentView()
-        links = self._links.boundLinks(view.document())
-        if not links:
-            return # the PDF contains no references to the current text document
-        
         s = links.indices(view.textCursor())
         if not s:
+            if s is False:
+                self.view.clearHighlight(self._highlightMusicFormat)
             return
-        self.view.center(self.destinationsRect(links.destinations()[s]).center())
-        self.highlight(links.destinations(), s, 10000)
-    
-    def destinationsRect(self, destinations):
-        """Return the rectangle containing all destinations."""
-        layout = self.view.surface().pageLayout()
-        rect = QRect()
-        for dest in destinations:
-            for pageNum, r in dest:
-                rect = rect.united(layout[pageNum].linkRect(r.normalized()))
-        # not larger than viewport
-        rect.setSize(rect.size().boundedTo(self.view.viewport().size()))
-        return rect
-    
+
+        if not scroll and self._highlightRange == s and self.view.isHighlighting(self._highlightMusicFormat):
+            return # don't redraw if same
+        self._highlightRange = s
+
+        # create the dict of areas
+        layout = self.view.pageLayout()
+        areas = collections.defaultdict(list)
+        for dest in links.destinations()[s]:
+            for pageNum, rect in dest:
+                areas[layout[pageNum]].append(rect)
+
+        if scroll:
+            # compute the bounding rect
+            boundingRect = QRect()
+            for page, rects in areas.items():
+                f = page.mapToPage(1, 1).rect
+                pbound = QRect()
+                for r in rects:
+                    pbound |= f(r)
+                boundingRect |= pbound.translated(page.pos())
+            self.view.ensureVisible(boundingRect, QMargins(20, 20, 20, 20))
+
+        if msec is None:
+            msec = 5000 if s.stop - s.start > 1 else 2000 # show selections longer
+        # RC: increased timer to give some time to the kinetic scrolling to complete.
+        if self.view.isScrolling():
+            msec += self.view.remainingScrollTime()
+        self.view.highlight(areas, self._highlightMusicFormat, msec)
+
     def showContextMenu(self):
         """Called when the user right-clicks or presses the context menu key."""
         pos = self.view.mapToGlobal(QPoint(0, 0))
@@ -322,26 +270,10 @@ class MusicView(QWidget):
         # mouse inside view?
         if self.view.mapFromGlobal(QCursor.pos()) in self.view.viewport().rect():
             pos = QCursor.pos()
-            pos_in_surface = self.view.surface().mapFromGlobal(pos)
-            page, link = self.view.surface().pageLayout().linkAt(pos_in_surface)
+            pos_in_viewport = self.view.viewport().mapFromGlobal(pos)
+            page, link = self.view.linkAt(pos_in_viewport)
             if link:
                 cursor = self._links.cursor(link, True)
         from . import contextmenu
         contextmenu.show(pos, self.parent(), link, cursor)
 
-
-class Highlighter(qpopplerview.Highlighter):
-    """Simple version of qpopplerview.Highlighter that has the color settable.
-    
-    You must set a color before using the Highlighter.
-    
-    """
-    def setColor(self, color):
-        """Sets the color to use to draw highlighting rectangles."""
-        self._color = color
-    
-    def color(self):
-        """Returns the color set using the setColor method."""
-        return self._color
-
-
