@@ -21,16 +21,15 @@
 Vocal part types.
 """
 
-from __future__ import unicode_literals
 
 import collections
 import itertools
 import re
 
-from PyQt4.QtCore import QRegExp, Qt
-from PyQt4.QtGui import (
-    QCheckBox, QComboBox, QGroupBox, QHBoxLayout, QLabel, QRegExpValidator,
-    QSpinBox, QVBoxLayout)
+from PyQt5.QtCore import QRegExp, Qt
+from PyQt5.QtGui import QRegExpValidator
+from PyQt5.QtWidgets import (
+    QCheckBox, QComboBox, QGroupBox, QHBoxLayout, QLabel, QSpinBox, QVBoxLayout)
 
 import listmodel
 import ly.dom
@@ -46,11 +45,11 @@ class VocalPart(_base.Part):
     def createWidgets(self, layout):
         self.createStanzaWidget(layout)
         self.createAmbitusWidget(layout)
-        
+
     def translateWidgets(self):
         self.translateStanzaWidget()
         self.translateAmbitusWidget()
-        
+
     def createStanzaWidget(self, layout):
         self.stanzas = QSpinBox(minimum=1, maximum=99, value=1)
         self.stanzasLabel = QLabel()
@@ -59,25 +58,25 @@ class VocalPart(_base.Part):
         box.addWidget(self.stanzasLabel)
         box.addWidget(self.stanzas)
         layout.addLayout(box)
-        
+
     def translateStanzaWidget(self):
         self.stanzasLabel.setText(_("Stanzas:"))
         self.stanzas.setToolTip(_("The number of stanzas."))
-    
+
     def createAmbitusWidget(self, layout):
         self.ambitus = QCheckBox()
         layout.addWidget(self.ambitus)
-        
+
     def translateAmbitusWidget(self):
         self.ambitus.setText(_("Ambitus"))
         self.ambitus.setToolTip(_(
             "Show the pitch range of the voice at the beginning of the staff."))
-    
+
     def assignLyrics(self, data, name, verse=0):
         """Creates an empty assignment for lyrics.
-        
+
         Returns the assignment.
-        
+
         """
         l = ly.dom.LyricMode()
         if verse:
@@ -88,13 +87,13 @@ class VocalPart(_base.Part):
         ly.dom.LineComment(_("Lyrics follow here."), l)
         ly.dom.BlankLine(l)
         return a
-    
+
     def addStanzas(self, data, node):
         """Add stanzas to the given (Voice) node.
-        
+
         The stanzas (as configured in self.stanzas.value()) are added
         using \\addlyrics.
-        
+
         """
         if self.stanzas.value() == 1:
             ly.dom.Identifier(self.assignLyrics(data, 'verse').name, ly.dom.AddLyrics(node))
@@ -107,7 +106,7 @@ class VocalSoloPart(VocalPart, _base.SingleVoicePart):
     """Base class for vocal solo parts."""
     octave = 1
     clef = None
-    
+
     def build(self, data, builder):
         super(VocalSoloPart, self).build(data, builder)
         stub = data.assignments[-1][0][-1]
@@ -123,7 +122,7 @@ class SopranoVoice(VocalSoloPart):
     @staticmethod
     def title(_=_base.translate):
         return _("Soprano")
-    
+
     @staticmethod
     def short(_=_base.translate):
         return _("abbreviation for Soprano", "S.")
@@ -133,7 +132,7 @@ class MezzoSopranoVoice(VocalSoloPart):
     @staticmethod
     def title(_=_base.translate):
         return _("Mezzo-soprano")
-    
+
     @staticmethod
     def short(_=_base.translate):
         return _("abbreviation for Mezzo-soprano", "Ms.")
@@ -143,11 +142,11 @@ class AltoVoice(VocalSoloPart):
     @staticmethod
     def title(_=_base.translate):
         return _("Alto")
-    
+
     @staticmethod
     def short(_=_base.translate):
         return _("abbreviation for Alto", "A.")
-    
+
     octave = 0
 
 
@@ -155,7 +154,7 @@ class TenorVoice(VocalSoloPart):
     @staticmethod
     def title(_=_base.translate):
         return _("Tenor")
-    
+
     @staticmethod
     def short(_=_base.translate):
         return _("abbreviation for Tenor", "T.")
@@ -168,7 +167,7 @@ class BassVoice(VocalSoloPart):
     @staticmethod
     def title(_=_base.translate):
         return _("Bass")
-    
+
     @staticmethod
     def short(_=_base.translate):
         return _("abbreviation for Bass", "B.")
@@ -181,7 +180,7 @@ class LeadSheet(VocalPart, _base.ChordNames):
     @staticmethod
     def title(_=_base.translate):
         return _("Lead sheet")
-    
+
     def createWidgets(self, layout):
         self.label = QLabel(wordWrap=True)
         self.chords = QGroupBox(checkable=True, checked=True)
@@ -193,7 +192,7 @@ class LeadSheet(VocalPart, _base.ChordNames):
         self.accomp = QCheckBox()
         layout.addWidget(self.accomp)
         VocalPart.createWidgets(self, layout)
-    
+
     def translateWidgets(self):
         VocalPart.translateWidgets(self)
         _base.ChordNames.translateWidgets(self)
@@ -208,9 +207,9 @@ class LeadSheet(VocalPart, _base.ChordNames):
 
     def build(self, data, builder):
         """Create chord names, song and lyrics.
-        
+
         Optionally a second staff with a piano accompaniment.
-        
+
         """
         if self.chords.isChecked():
             _base.ChordNames.build(self, data, builder)
@@ -295,7 +294,7 @@ class Choir(VocalPart):
         self.lyrics.setCurrentIndex(0)
         self.pianoReduction = QCheckBox()
         self.rehearsalMidi = QCheckBox()
-        
+
         layout.addWidget(self.label)
         box = QHBoxLayout()
         layout.addLayout(box)
@@ -309,7 +308,7 @@ class Choir(VocalPart):
         self.createAmbitusWidget(layout)
         layout.addWidget(self.pianoReduction)
         layout.addWidget(self.rehearsalMidi)
-    
+
     def translateWidgets(self):
         self.translateStanzaWidget()
         self.translateAmbitusWidget()
@@ -337,7 +336,7 @@ class Choir(VocalPart):
         staves = re.sub('-+', '-', staves).strip('-')
         if not staves:
             return
-        
+
         splitStaves = staves.split('-')
         numStaves = len(splitStaves)
         staffCIDs = collections.defaultdict(int)    # number same-name staff Context-IDs
@@ -347,29 +346,29 @@ class Choir(VocalPart):
         lyrics = collections.defaultdict(list)      # lyrics grouped by stanza number
         pianoReduction = collections.defaultdict(list)
         rehearsalMidis = []
-        
+
         p = ly.dom.ChoirStaff()
         choir = ly.dom.Sim(p)
         data.nodes.append(p)
-        
+
         # print main instrumentName if there are more choirs, and we
         # have more than one staff.
         if numStaves > 1 and data.num:
             builder.setInstrumentNames(p,
                 builder.instrumentName(lambda _: _("Choir"), data.num),
                 builder.instrumentName(lambda _: _("abbreviation for Choir", "Ch."), data.num))
-        
+
         # get the preferred way of adding lyrics
         lyrAllSame, lyrEachSame, lyrEachDiff, lyrSpread = (
             self.lyrics.currentIndex() == i for i in range(4))
         lyrEach = lyrEachSame or lyrEachDiff
-        
+
         # stanzas to print (0 = don't print stanza number):
         if numStanzas == 1:
             allStanzas = [0]
         else:
             allStanzas = list(range(1, numStanzas + 1))
-        
+
         # Which stanzas to print where:
         if lyrSpread and numStanzas > 1 and numStaves > 2:
             spaces = numStaves - 1
@@ -381,7 +380,7 @@ class Choir(VocalPart):
                                 itertools.repeat(count, numStaves - rest)))
         else:
             stanzaGroups = itertools.repeat(allStanzas, numStaves)
-        
+
         # a function to set staff affinity (in LilyPond 2.13.4 and above):
         if builder.lyVersion >= (2, 13, 4):
             def setStaffAffinity(context, affinity):
@@ -390,7 +389,7 @@ class Choir(VocalPart):
         else:
             def setStaffAffinity(lyricsContext, affinity):
                 pass
-        
+
         # a function to make a column markup:
         if builder.lyVersion >= (2, 11, 57):
             columnCommand = 'center-column'
@@ -402,7 +401,7 @@ class Choir(VocalPart):
             for name in names:
                 ly.dom.QuotedString(name, column)
             return node
-        
+
         stavesLeft = numStaves
         for staff, stanzas in zip(splitStaves, stanzaGroups):
             # are we in the last staff?
@@ -414,7 +413,7 @@ class Choir(VocalPart):
             # Create the staff for the voices
             s = ly.dom.Staff(parent=choir)
             builder.setMidiInstrument(s, self.midiInstrument)
-            
+
             # Build a list of the voices in this staff.
             # Each entry is a tuple(name, num).
             # name is one of 'S', 'A', 'T', or 'B'
@@ -425,7 +424,7 @@ class Choir(VocalPart):
                 if staves.count(voice) > 1:
                     voiceCounter[voice] += 1
                 voices.append((voice, voiceCounter[voice]))
-            
+
             # Add the instrument names to the staff:
             if numVoices == 1:
                 voice, num = voices[0]
@@ -440,13 +439,13 @@ class Choir(VocalPart):
                 shortNames = makeColumnMarkup(
                     builder.instrumentName(voice2Voice[voice].short, num) for voice, num in voices)
                 builder.setInstrumentNames(s, longNames, shortNames)
-            
+
             # Make the { } or << >> holder for this staff's children.
             # If *all* staves have only one voice, addlyrics is used.
             # In that case, don't remove the braces.
             staffMusic = (ly.dom.Seq if lyrEach and maxNumVoices == 1 else
                           ly.dom.Seqr if numVoices == 1 else ly.dom.Simr)(s)
-            
+
             # Set the clef for this staff:
             if 'B' in staff:
                 ly.dom.Clef('bass', staffMusic)
@@ -466,14 +465,14 @@ class Choir(VocalPart):
                 order = 1, 3, 2, 4
             else:
                 order = range(1, numVoices + 1)
-            
+
             # What name would the staff get if we need to refer to it?
             # If a name (like 's' or 'sa') is already in use in this part,
             # just add a number ('ss2' or 'sa2', etc.)
             staffCIDs[staff] += 1
             cid = ly.dom.Reference(staff.lower() +
                 str(staffCIDs[staff] if staffCIDs[staff] > 1 else ""))
-            
+
             # Create voices and their lyrics:
             for (voice, num), voiceNum in zip(voices, order):
                 name = voice2id[voice]
@@ -481,7 +480,7 @@ class Choir(VocalPart):
                     name += ly.util.int2text(num)
                 a = data.assignMusic(name, voice2Voice[voice].octave)
                 lyrName = name + 'Verse' if lyrEachDiff else 'verse'
-            
+
                 # Use \addlyrics if all staves have exactly one voice.
                 if lyrEach and maxNumVoices == 1:
                     for verse in stanzas:
@@ -494,7 +493,7 @@ class Choir(VocalPart):
                     if voiceNum:
                         ly.dom.Text('\\voice' + ly.util.int2text(voiceNum), voiceMusic)
                     ly.dom.Identifier(a.name, voiceMusic)
-                    
+
                     if stanzas and (lyrEach or (voiceNum <= 1 and
                                     (stavesLeft or numStaves == 1))):
                         # Create the lyrics. If they should be above the staff,
@@ -520,10 +519,10 @@ class Choir(VocalPart):
                     if voiceNum > 1:
                         ly.dom.Line("\\override Ambitus #'X-offset = #{0}".format(
                                  (voiceNum - 1) * 2.0), ambitusContext)
-            
+
                 pianoReduction[voice].append(a.name)
                 rehearsalMidis.append((voice, num, a.name, lyrName))
-            
+
         # Assign the lyrics, so their definitions come after the note defs.
         # (These refs are used again below in the midi rehearsal routine.)
         refs = {}
@@ -538,17 +537,17 @@ class Choir(VocalPart):
             a = data.assign('pianoReduction')
             data.nodes.append(ly.dom.Identifier(a.name))
             piano = ly.dom.PianoStaff(parent=a)
-            
+
             sim = ly.dom.Sim(piano)
             rightStaff = ly.dom.Staff(parent=sim)
             leftStaff = ly.dom.Staff(parent=sim)
             right = ly.dom.Seq(rightStaff)
             left = ly.dom.Seq(leftStaff)
-            
+
             # Determine the ordering of voices in the staves
             upper = pianoReduction['S'] + pianoReduction['A']
             lower = pianoReduction['T'] + pianoReduction['B']
-            
+
             preferUpper = 1
             if not upper:
                 # Male choir
@@ -567,14 +566,14 @@ class Choir(VocalPart):
             # Otherwise accidentals can be confusing
             ly.dom.Line("#(set-accidental-style 'piano)", right)
             ly.dom.Line("#(set-accidental-style 'piano)", left)
-            
+
             # Move voices if unevenly spread
             if abs(len(upper) - len(lower)) > 1:
                 voices = upper + lower
                 half = (len(voices) + preferUpper) // 2
                 upper = voices[:half]
                 lower = voices[half:]
-            
+
             for staff, voices in (ly.dom.Simr(right), upper), (ly.dom.Simr(left), lower):
                 if voices:
                     for v in voices[:-1]:
@@ -586,30 +585,30 @@ class Choir(VocalPart):
             ly.dom.Line("fontSize = #-1", piano.getWith())
             ly.dom.Line("\\override StaffSymbol #'staff-space = #(magstep -1)",
                 piano.getWith())
-            
+
             # Nice to add Mark engravers
             ly.dom.Line('\\consists "Mark_engraver"', rightStaff.getWith())
             ly.dom.Line('\\consists "Metronome_mark_engraver"', rightStaff.getWith())
-            
+
             # Keep piano reduction out of the MIDI output
             if builder.midi:
                 ly.dom.Line('\\remove "Staff_performer"', rightStaff.getWith())
                 ly.dom.Line('\\remove "Staff_performer"', leftStaff.getWith())
-        
+
         # Create MIDI files if desired
         if self.rehearsalMidi.isChecked():
             a = data.assign('rehearsalMidi')
             rehearsalMidi = a.name
-            
+
             func = ly.dom.SchemeList(a)
             func.pre = '#\n(' # hack
             ly.dom.Text('define-music-function', func)
             ly.dom.Line('(parser location name midiInstrument lyrics) '
                  '(string? string? ly:music?)', func)
             choir = ly.dom.Sim(ly.dom.Command('unfoldRepeats', ly.dom.SchemeLily(func)))
-            
+
             data.afterblocks.append(ly.dom.Comment(_("Rehearsal MIDI files:")))
-            
+
             for voice, num, ref, lyrName in rehearsalMidis:
                 # Append voice to the rehearsalMidi function
                 name = voice2id[voice] + str(num or '')
@@ -617,9 +616,9 @@ class Choir(VocalPart):
                 if builder.lyVersion < (2, 18, 0):
                     ly.dom.Text('<>\\f', seq) # add one dynamic
                 ly.dom.Identifier(ref, seq) # add the reference to the voice
-                
+
                 book = ly.dom.Book()
-                
+
                 # Append score to the aftermath (stuff put below the main score)
                 suffix = "choir{0}-{1}".format(data.num, name) if data.num else name
                 if builder.lyVersion < (2, 12, 0):
@@ -630,7 +629,7 @@ class Choir(VocalPart):
                 data.afterblocks.append(book)
                 data.afterblocks.append(ly.dom.BlankLine())
                 score = ly.dom.Score(book)
-                
+
                 # TODO: make configurable
                 midiInstrument = voice2Midi[voice]
 
@@ -639,7 +638,7 @@ class Choir(VocalPart):
                 ly.dom.QuotedString(midiInstrument, cmd)
                 ly.dom.Identifier(refs[(lyrName, allStanzas[0])], cmd)
                 ly.dom.Midi(score)
-            
+
             ly.dom.Text("\\context Staff = $name", choir)
             seq = ly.dom.Seq(choir)
             ly.dom.Line("\\set Score.midiMinimumVolume = #0.5", seq)
