@@ -263,7 +263,7 @@ r"""-*- menu: blocks; name: repunf; selection: strip;
 'relative': T(_("Relative Music"),
 r"""-*- name: rel;
 \relative c$CURSOR'$ANCHOR {
-""" '   $SELECTION' r"""  
+""" '   $SELECTION' r"""
 }"""),
 
 
@@ -473,7 +473,7 @@ def main():
             break
     else:
         s = 'lilypond'
-    
+
     def html(text):
         if text:
             text = text.replace('<!-- ', '')
@@ -481,7 +481,7 @@ def main():
             text = text.replace('<!--', '')
             text = text.replace('-->', '')
             return text
-    
+
     def lilypond(text):
         if text.lstrip().startswith('%{'):
             if text.lstrip().startswith('%{ '):
@@ -496,10 +496,10 @@ def main():
                 text = cursor.selection().toPlainText()
             text = re.compile(r'^(\s*)%+ ?', re.M).sub(r'\1', text)
         return text
-    
+
     def scheme(text):
         return re.compile(r'^(\s*);+', re.M).sub(r'\1', text)
-    
+
     if s == 'lilypond':
         text = lilypond(text)
     elif s == 'html':
@@ -521,33 +521,9 @@ if state[-1] != 'paper':
 """),
 
 
-'document_fonts': T(_("Document Fonts..."),
-r"""-*- menu: paper; name: fo; python; icon: preferences-desktop-font;
-snippet = '''\
-fonts = #
-(make-pango-font-tree
-  "{roman}"
-  "{sans}"
-  "{typewriter}"
-  (/ (* staff-height pt) 2.5))
-'''
-
-import globalfontdialog
-dlg = globalfontdialog.GlobalFontDialog(view)
-if dlg.exec_():
-    text = snippet.format(
-        roman = dlg.romanFont(),
-        sans = dlg.sansFont(),
-        typewriter = dlg.typewriterFont())
-    if state[-1] != "paper":
-        text = "\\paper {{\n{0}}}\n".format(text)
-
-"""),
-
-
 'last_note': T(_("Last note or chord"),
 r"""-*- python; menu: music; symbol: note_ellipsis;
-# This snippet reads back the last entered note or chord and 
+# This snippet reads back the last entered note or chord and
 # inserts it again. It removes the octave mark from a note of the first
 # note of a chord if the music is in relative mode.
 
@@ -669,7 +645,7 @@ global = {
 chordNames = \chordmode {
   \global
   c1
-  
+
 }
 
 melody = \relative c'' {
@@ -679,8 +655,8 @@ melody = \relative c'' {
 }
 
 words = \lyricmode {
-  
-  
+
+
 }
 
 \score {
@@ -713,43 +689,43 @@ global = {
 soprano = \relative c'' {
   \global
   $CURSORc4
-  
+
 }
 
 alto = \relative c' {
   \global
   c4
-  
+
 }
 
 tenor = \relative c' {
   \global
   c4
-  
+
 }
 
 bass = \relative c {
   \global
   c4
-  
+
 }
 
 verseOne = \lyricmode {
   \set stanza = "1."
   hi
-  
+
 }
 
 verseTwo = \lyricmode {
   \set stanza = "2."
   ha
-  
+
 }
 
 verseThree = \lyricmode {
   \set stanza = "3."
   ho
-  
+
 }
 
 \score {
@@ -785,5 +761,44 @@ verseThree = \lyricmode {
 """),
 
 
+'template_blank_sheet_music_paper': T(_("Blank Music Sheet"),
+r"""-*- template; indent: no; template-run;
+\version "${LILYPOND_VERSION}"
+
+{
+  \repeat unfold 12${CURSOR}
+  {
+    s1
+    \break
+  }
 }
 
+\layout {
+  \context {
+    \Score
+    \remove "Bar_number_engraver"
+  }
+  \context {
+    \Staff
+    \remove "Clef_engraver"
+    \remove "Time_signature_engraver"
+    \remove "Bar_engraver"
+  }
+}
+
+\paper {
+  indent = 0
+  ragged-last-bottom = ##f
+  top-system-spacing = #'((minimum-distance . 10))
+  last-bottom-spacing = #'((minimum-distance . 10))
+}
+
+\header {
+  tagline = ##f
+}
+
+"""),
+
+
+
+}
